import { Injectable } from '@nestjs/common';
import { RabbitSubscribe } from '@mobicoop/message-broker-module';
import { CommandBus } from '@nestjs/cqrs';
import { MATCHER_AD_CREATED_MESSAGE_HANDLER } from '@src/app.constants';
import { MatcherAdCreatedIntegrationEvent } from './matcher-ad.types';
import { ValidateAdCommand } from '@modules/ad/core/application/commands/validate-ad/validate-ad.command';

@Injectable()
export class MatcherAdCreatedMessageHandler {
  constructor(private readonly commandBus: CommandBus) {}

  @RabbitSubscribe({
    name: MATCHER_AD_CREATED_MESSAGE_HANDLER,
  })
  public async matcherAdCreated(message: string) {
    try {
      const matcherAdCreatedIntegrationEvent: MatcherAdCreatedIntegrationEvent =
        JSON.parse(message);
      await this.commandBus.execute(
        new ValidateAdCommand({
          id: matcherAdCreatedIntegrationEvent.id,
        }),
      );
    } catch (error: any) {
      // do not throw error to acknowledge incoming message
      // error handling should be done in the command handler, if relevant
    }
  }
}
