import { hasValidPositionIndexes } from '@modules/ad/interface/grpc-controllers/dtos/validators/has-valid-position-indexes.validator';
import { WaypointDto } from '@modules/ad/interface/grpc-controllers/dtos/waypoint.dto';

describe('addresses position validator', () => {
  const waypoint1: WaypointDto = {
    position: 0,
    lat: 48.689445,
    lon: 6.17651,
    houseNumber: '5',
    street: 'Avenue Foch',
    locality: 'Nancy',
    postalCode: '54000',
    country: 'France',
  };
  const waypoint2: WaypointDto = {
    position: 1,
    lat: 48.8566,
    lon: 2.3522,
    locality: 'Paris',
    postalCode: '75000',
    country: 'France',
  };
  const waypoint3: WaypointDto = {
    position: 2,
    lon: 49.2628,
    lat: 4.0347,
    locality: 'Reims',
    postalCode: '51454',
    country: 'France',
  };

  it('should not validate if multiple positions have same value', () => {
    expect(
      hasValidPositionIndexes([waypoint1, waypoint1, waypoint2]),
    ).toBeFalsy();
  });
  it('should not validate if positions are not consecutives', () => {
    expect(hasValidPositionIndexes([waypoint1, waypoint3])).toBeFalsy();
  });
  it('should not validate if waypoints are empty', () => {
    expect(hasValidPositionIndexes([])).toBeFalsy();
  });
  it('should validate if all positions are ordered', () => {
    expect(
      hasValidPositionIndexes([waypoint1, waypoint2, waypoint3]),
    ).toBeTruthy();
    waypoint1.position = 1;
    waypoint2.position = 2;
    waypoint3.position = 3;
    expect(
      hasValidPositionIndexes([waypoint1, waypoint2, waypoint3]),
    ).toBeTruthy();
  });
});
